/* Copyright (C) 2005, 2006 Hartmut Holzgraefe, MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include <stdio.h>
#include <stdlib.h>

#include <ndb_init.h>
#include <mgmapi.h>
#include <mgmapi_debug.h>
#include <ndb_logevent.h>

#define DBTUP 0xf8 // DBTUP block reports data usage
#define DBTUX 0xf9 // DBTUX block reports index usage

#define CONNECT_STRING "localhost"

int main(int argc, char **argv)
{
  NdbMgmHandle handle;
  struct ndb_mgm_cluster_state *cluster_state;
  struct ndb_mgm_node_state    *node_state;

#define PRINT_CATEGORY(x) printf("%-35s %d\n", #x, x);

  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_STARTUP);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_SHUTDOWN);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_STATISTIC);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_CHECKPOINT);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_NODE_RESTART);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_CONNECTION);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_INFO);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_ERROR);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_CONGESTION);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_DEBUG);
  PRINT_CATEGORY(NDB_MGM_EVENT_CATEGORY_BACKUP);


  ndb_init();

  // creating connection handle, setting conncet string
  handle = ndb_mgm_create_handle();
  ndb_mgm_set_connectstring(handle, CONNECT_STRING);

 
  // establish connections
  if (ndb_mgm_connect(handle, 5, 1, 1) < 0) {
	  ndb_mgm_destroy_handle(&handle);
	  exit(3);
  }
  cluster_state = ndb_mgm_get_status(handle);
  if (cluster_state == NULL) {
	ndb_mgm_disconnect(handle);
	ndb_mgm_destroy_handle(&handle);
	exit(3);
  }

  // MemoryUsage events are issued in the statistics category at log level 5
  // so we filter out anything not statistics related or at a log level 6-15
  int filter[] = { 15, NDB_MGM_EVENT_CATEGORY_STARTUP,
                   15, NDB_MGM_EVENT_CATEGORY_SHUTDOWN,
                   15, NDB_MGM_EVENT_CATEGORY_STATISTIC,
                   15, NDB_MGM_EVENT_CATEGORY_CHECKPOINT,
                   15, NDB_MGM_EVENT_CATEGORY_NODE_RESTART,
                   15, NDB_MGM_EVENT_CATEGORY_CONNECTION,
                   15, NDB_MGM_EVENT_CATEGORY_INFO,
                   15, NDB_MGM_EVENT_CATEGORY_ERROR,
                   15, NDB_MGM_EVENT_CATEGORY_CONGESTION,
                   15, NDB_MGM_EVENT_CATEGORY_DEBUG,
                   15, NDB_MGM_EVENT_CATEGORY_BACKUP,
                   0 };

  struct ndb_logevent_handle * le_handle= ndb_mgm_create_logevent_handle(handle, filter);
  struct ndb_logevent le;
  int status;
  
  // event loop
  do {
	status = ndb_logevent_get_next(le_handle, &le, 1000 /* 1 sec timeout */);

	if (status == 1) { // event received successfully, no timeout

          printf("Category: %d\n", le.category);

	  switch (le.type) { // handle events by type
	    default:
		  break;
	  }

	}

  } while (status >= 0);

  printf("Ended with status %d\n", status);

  exit(0);
}
